pub struct TryInsertBatchError {
pub bundle_type: DebugName,
pub entities: Vec<Entity>,
}Expand description
The error type returned by World::try_insert_batch and World::try_insert_batch_if_new
if any of the provided entities do not exist.
Fields
bundle_type: DebugNameThe bundles’ type name.
entities: Vec<Entity>The IDs of the provided entities that do not exist.